@@ -10,10 +10,13 @@ a probability density function for the principal stress components.
 
 __author__ = """Jeff Burghardt"""
 __email__ = 'jeffrey.burghardt@pnnl.gov'
-__version__ = '0.2.5'
+__version__ = '0.3.0'
 
-from .stress_state import StressState
+from .stress_state import StressState, units
 from .constraints import FaultConstraint
 from .constraints import FaultingRegimeConstraint, SU
 from .constraints import BreakoutConstraint
+from .constraints import DITFConstraint
 from .constraints import StressMeasurement
+from .samplers import RejectionSampler
+from .risk_analysis import CriticalFaultActivation
